import { Subject } from 'rxjs';
import { DashboardViewBase } from '@/studio-core';
import HRDutyService from '@/service/hrduty/hrduty-service';
import HRDutyAuthService from '@/authservice/hrduty/hrduty-auth-service';
import PortalViewEngine from '@engine/view/portal-view-engine';
import HRDutyUIService from '@/uiservice/hrduty/hrduty-ui-service';

/**
 * 职务看板视图基类
 *
 * @export
 * @class HRDutyDashboardViewBase
 * @extends {DashboardViewBase}
 */
export class HRDutyDashboardViewBase extends DashboardViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HRDutyDashboardViewBase
     */
    protected appDeName: string = 'hrduty';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HRDutyDashboardViewBase
     */
    protected appDeKey: string = 'hrdutyid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HRDutyDashboardViewBase
     */
    protected appDeMajor: string = 'hrdutyname';

    /**
     * 实体服务对象
     *
     * @type {HRDutyService}
     * @memberof HRDutyDashboardViewBase
     */
    protected appEntityService: HRDutyService = new HRDutyService;

    /**
     * 实体权限服务对象
     *
     * @type HRDutyUIService
     * @memberof HRDutyDashboardViewBase
     */
    public appUIService: HRDutyUIService = new HRDutyUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HRDutyDashboardViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HRDutyDashboardViewBase
     */
    protected model: any = {
        srfCaption: 'entities.hrduty.views.dashboardview.caption',
        srfTitle: 'entities.hrduty.views.dashboardview.title',
        srfSubTitle: 'entities.hrduty.views.dashboardview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HRDutyDashboardViewBase
     */
    protected containerModel: any = {
        view_dashboard: { name: 'dashboard', type: 'DASHBOARD' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '532833b3a07947f04a46adcc957a0ca6';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HRDutyDashboardViewBase
     */
    public engine: PortalViewEngine = new PortalViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HRDutyDashboardViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            dashboard: this.$refs.dashboard,
            keyPSDEField: 'hrduty',
            majorPSDEField: 'hrdutyname',
            isLoadDefault: true,
        });
    }

    /**
     * dashboard 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyDashboardViewBase
     */
    public dashboard_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('dashboard', 'load', $event);
    }


}