import { Subject } from 'rxjs';
import { PickupGridViewBase } from '@/studio-core';
import HRDutyService from '@/service/hrduty/hrduty-service';
import HRDutyAuthService from '@/authservice/hrduty/hrduty-auth-service';
import PickupGridViewEngine from '@engine/view/pickup-grid-view-engine';
import HRDutyUIService from '@/uiservice/hrduty/hrduty-ui-service';

/**
 * 职务选择表格视图视图基类
 *
 * @export
 * @class HRDutyPickupGridViewBase
 * @extends {PickupGridViewBase}
 */
export class HRDutyPickupGridViewBase extends PickupGridViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HRDutyPickupGridViewBase
     */
    protected appDeName: string = 'hrduty';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HRDutyPickupGridViewBase
     */
    protected appDeKey: string = 'hrdutyid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HRDutyPickupGridViewBase
     */
    protected appDeMajor: string = 'hrdutyname';

    /**
     * 实体服务对象
     *
     * @type {HRDutyService}
     * @memberof HRDutyPickupGridViewBase
     */
    protected appEntityService: HRDutyService = new HRDutyService;

    /**
     * 实体权限服务对象
     *
     * @type HRDutyUIService
     * @memberof HRDutyPickupGridViewBase
     */
    public appUIService: HRDutyUIService = new HRDutyUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HRDutyPickupGridViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HRDutyPickupGridViewBase
     */
    protected model: any = {
        srfCaption: 'entities.hrduty.views.pickupgridview.caption',
        srfTitle: 'entities.hrduty.views.pickupgridview.title',
        srfSubTitle: 'entities.hrduty.views.pickupgridview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HRDutyPickupGridViewBase
     */
    protected containerModel: any = {
        view_grid: { name: 'grid', type: 'GRID' },
        view_searchform: { name: 'searchform', type: 'SEARCHFORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'de53ae7d577a526b3b268951df885868';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HRDutyPickupGridViewBase
     */
    public engine: PickupGridViewEngine = new PickupGridViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HRDutyPickupGridViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            grid: this.$refs.grid,
            searchform: this.$refs.searchform,
            keyPSDEField: 'hrduty',
            majorPSDEField: 'hrdutyname',
            isLoadDefault: true,
        });
    }

    /**
     * grid 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyPickupGridViewBase
     */
    public grid_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'selectionchange', $event);
    }

    /**
     * grid 部件 beforeload 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyPickupGridViewBase
     */
    public grid_beforeload($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'beforeload', $event);
    }

    /**
     * grid 部件 rowdblclick 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyPickupGridViewBase
     */
    public grid_rowdblclick($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'rowdblclick', $event);
    }

    /**
     * grid 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyPickupGridViewBase
     */
    public grid_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'load', $event);
    }

    /**
     * searchform 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyPickupGridViewBase
     */
    public searchform_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'save', $event);
    }

    /**
     * searchform 部件 search 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyPickupGridViewBase
     */
    public searchform_search($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'search', $event);
    }

    /**
     * searchform 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyPickupGridViewBase
     */
    public searchform_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'load', $event);
    }



    /**
     * 是否展开搜索表单
     *
     * @protected
     * @type {boolean}
     * @memberof HRDutyPickupGridViewBase
     */
    protected isExpandSearchForm: boolean = true;


}