import { Subject } from 'rxjs';
import { EditViewBase } from '@/studio-core';
import HRDutyService from '@/service/hrduty/hrduty-service';
import HRDutyAuthService from '@/authservice/hrduty/hrduty-auth-service';
import EditViewEngine from '@engine/view/edit-view-engine';
import HRDutyUIService from '@/uiservice/hrduty/hrduty-ui-service';

/**
 * 职务信息视图基类
 *
 * @export
 * @class HRDutyV_002Base
 * @extends {EditViewBase}
 */
export class HRDutyV_002Base extends EditViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HRDutyV_002Base
     */
    protected appDeName: string = 'hrduty';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HRDutyV_002Base
     */
    protected appDeKey: string = 'hrdutyid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HRDutyV_002Base
     */
    protected appDeMajor: string = 'hrdutyname';

    /**
     * 实体服务对象
     *
     * @type {HRDutyService}
     * @memberof HRDutyV_002Base
     */
    protected appEntityService: HRDutyService = new HRDutyService;

    /**
     * 实体权限服务对象
     *
     * @type HRDutyUIService
     * @memberof HRDutyV_002Base
     */
    public appUIService: HRDutyUIService = new HRDutyUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HRDutyV_002Base
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HRDutyV_002Base
     */
    protected model: any = {
        srfCaption: 'entities.hrduty.views.v_002.caption',
        srfTitle: 'entities.hrduty.views.v_002.title',
        srfSubTitle: 'entities.hrduty.views.v_002.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HRDutyV_002Base
     */
    protected containerModel: any = {
        view_form: { name: 'form', type: 'FORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '54e70bcf034bf3715d121537bc8d1d77';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HRDutyV_002Base
     */
    public engine: EditViewEngine = new EditViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HRDutyV_002Base
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            form: this.$refs.form,
            p2k: '0',
            keyPSDEField: 'hrduty',
            majorPSDEField: 'hrdutyname',
            isLoadDefault: true,
        });
    }

    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyV_002Base
     */
    public form_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'save', $event);
    }

    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyV_002Base
     */
    public form_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }

    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyV_002Base
     */
    public form_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'load', $event);
    }


}